/* 
    BINDING.CC
    Programmer: Ken Mayer
    Date......: 01/30/1998

    Provided as an example for the BorCon 98 paper on
    Tips and Tricks with Reports and Labels
    by Ken Mayer

    A simple text control that should handle pageTemplate offsets
    so that when printing, the pageTemplate itself is offset properly
    to handle bindings ... the idea is that odd number pages are
    normally on the right side, so need a larger left margin; and
    conversely even number pages are on the left, and need a larger
    right margin. This text control would be used in place of the
    custom control that ships with Visual dBASE, which places
    the pageNumber onto the report.

    NOTE: The margin changes for the report are done by changing
    the marginLeft and marginRight based on the binding ... 
       this.BindingSide    = the side that is closest to the binding
       this.NonBindingSide = the other side -- furthest from the
                             binding

    WARNING: This assumes you are using the default "pageTemplate1"
    
*/
class BindingPageNumber(ParentObj) of Text(ParentObj) custom 

    with ( this )

       text   := class::pageValue 
       height := .15
       width  := .75
       metric := 3   // Inches

    endwith

    function PageValue
      nPageNo = this.form.reportPage
      if mod( nPageNo, 2 ) == 0 // even number
         form.pageTemplate1.marginLeft  := .25
         form.pageTemplate1.marginRight := .75
      else
         form.pageTemplate1.marginLeft  := .75
         form.pageTemplate1.marginRight := .25
      endif
    return ( nPageNo )

endclass

