/*
    HTMLPAGE.PRG
    Programmer: Ken Mayer
    Date......: 02/20/1998

    A simple program to take a Visual dBASE 7 report and 
    generate multiple HTML files, one page of the report
    per file, with links to the Previous and Next pages
    of the report (if needed).

    Provided as an example for the BorCon 98 paper on
    Tips and Tricks with Reports and Labels
    by Ken Mayer

    ASSUMPTIONS:
    a) there is only 1 pageTemplate, using default 
       pageTemplate name of "pageTemplate1"
    b) That there is room at the bottom of the page
       (between the pageTemplate edge and the streamFrame edge)
       to place text controls


    NOTE: This requires a parameter for the report name ...

    DO HTMLPAGE WITH "reportname.rep"  or   
    DO HTMLPAGE WITH "reportname"
*/


// deal with missing report name:
if argCount() = 0
   msgbox( "Need a report name to work with ...", ;
           "Can't function", 16 )
   return
endif

// check to see if report exists:
cFile = argVector(1)
if upper( right( cFile, 4 ) ) # ".REP"
   cFile = cFile + ".REP"
endif

if not file( cFile )
   msgbox( "Report file: "+cFile+" does not exist!", ;
           "Can't function", 16 )
   return
endif

// Ok. At this point, the .REP file exists, let's get
// the className from the constructor code:
f = new File()
f.open( cFile )
do while not f.eof()
   cLine = upper( f.Gets() )
   if "CLASS" $ cLine // hopefully this is the correct
                      // line -- i.e. the word 'class' doesn't
                      // appear in comments at the beginning
                      // of the source for some reason ...
      nFirstSpace = at( " ", cLine )
      nNextSpace  = at( " ", cLine, 2 )
      cReportName = substr( cLine, nFirstSpace+1, ( nNextSpace-nFirstSpace ) )
      exit
   endif
   
enddo
f.close()

// Next, create an instance of the report ...:
set procedure to &cFile. additive
rMyRep = new &cReportName.()
rMyRep.outPut = 4 // HTML
cFile2 = cFile.left( cFile.indexOf( "." ) ) // no .REP

// We have an instance of this report, so now for the hard parts ...

// set metrics to something understandable:
rMyRep.metrics = 3 // Inches

// add text controls for linking purposes:
rMyRep.pageTemplate1.PreviousLink = new Text( rMyRep.pageTemplate1 )
with ( rMyRep.pageTemplate1.PreviousLink )
     text = "[ Previous Page ]"  // this will be changed
                                 // below to include HREF ...
     top  = rMyRep.pageTemplate1.height - .25 // quarter inch
     left = 1 // 1 inch
     width = 1.5 // 1.5 inches
     canRender = {|| ( rMyRep.reportPage > 1 ) }
endwith

// set text property for this one here -- for whatever reason,
// this doesn't evaluate in loop the first time.
rMyRep.pageTemplate1.NextLink = new Text( rMyRep.pageTemplate1 )
with ( rMyRep.pageTemplate1.NextLink )
     text = "<A HREF='"+cFile2+"2.htm'>[ Next Page ]</A>"  
     top  = rMyRep.pageTemplate1.height - .25 // quarter inch
     left = 3 //  3 inches
     width = 1.5 // 1.5 inches?
     canRender = {|| not rMyRep.isLastPage() }
endwith

// Loop through report until we come to the last page (using the
// reportname.isLastPage() method)
do while true

   // store this so we can refer to it throughout code:
   nPage = rMyRep.startPage
   rMyRep.endPage = nPage // same page as startpage

   // set the outputFilename:
   rMyRep.outputFileName = cFile2+nPage+".HTM"

   // set text controls for links
   if nPage > 1 
      // create "Previous" link
      rMyRep.pageTemplate1.PreviousLink.text = ;
         "<A HREF='"+cFile2+( nPage - 1 )+;
                   ".HTM'>[ Previous Page ]</A>"
   endif

   // NEXT page link should run for page 1 through the
   // next to last page ... (and if we are doing a single
   // page report, well, don't put this link there!)
   if nPage => 1 and not rMyRep.isLastPage()
      // create "Next" link
      rMyRep.pageTemplate1.NextLink.text = ;
         "<A HREF='"+cFile2+( nPage + 1 )+;
                   ".HTM'>[ Next Page ]</A>"
   endif

   rMyRep.Render()     // render page of report

   // Check to see if we're done ...
   if rMyRep.isLastPage()
      exit
   endif

   // otherwise
   rMyRep.startPage++  // increment startPage

enddo

// a bit of cleanup:
close procedure &cFile.
rMyRep.release()

/* ------------------------------------------------------------
   End of Program: HTMLPAGES.PRG
   ------------------------------------------------------------ */

